@@ -1285,7 +1285,7 @@ class GenTest(unittest.TestCase):
         self.executeClean(cmd)
         self.compareFiles('{}.py'.format(t_), '{}2.py'.format(t_))
         # cleanup generated files
-        self.remove('{}.py'.format(t_))
+        #self.remove('{}.py'.format(t_))
 
     def compareFiles(self, left, right, ignore=None):
         left = os.path.join(TEST_DIR, left)
